# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApiArgs', 'Api']

@pulumi.input_type
class ApiArgs:
    def __init__(__self__, *,
                 api_management_name: pulumi.Input[str],
                 resource_group_name: pulumi.Input[str],
                 revision: pulumi.Input[str],
                 api_type: Optional[pulumi.Input[str]] = None,
                 contact: Optional[pulumi.Input['ApiContactArgs']] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 import_: Optional[pulumi.Input['ApiImportArgs']] = None,
                 license: Optional[pulumi.Input['ApiLicenseArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 oauth2_authorization: Optional[pulumi.Input['ApiOauth2AuthorizationArgs']] = None,
                 openid_authentication: Optional[pulumi.Input['ApiOpenidAuthenticationArgs']] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 revision_description: Optional[pulumi.Input[str]] = None,
                 service_url: Optional[pulumi.Input[str]] = None,
                 source_api_id: Optional[pulumi.Input[str]] = None,
                 subscription_key_parameter_names: Optional[pulumi.Input['ApiSubscriptionKeyParameterNamesArgs']] = None,
                 subscription_required: Optional[pulumi.Input[bool]] = None,
                 terms_of_service_url: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 version_description: Optional[pulumi.Input[str]] = None,
                 version_set_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Api resource.
        :param pulumi.Input[str] api_management_name: The Name of the API Management Service where this API should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The Name of the Resource Group where the API Management API exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision: The Revision which used for this API. Changing this forces a new resource to be created.
        :param pulumi.Input[str] api_type: Type of API. Possible values are `graphql`, `http`, `soap`, and `websocket`. Defaults to `http`.
        :param pulumi.Input['ApiContactArgs'] contact: A `contact` block as documented below.
        :param pulumi.Input[str] description: A description of the API Management API, which may include HTML formatting tags.
        :param pulumi.Input[str] display_name: The display name of the API.
        :param pulumi.Input['ApiImportArgs'] import_: A `import` block as documented below.
        :param pulumi.Input['ApiLicenseArgs'] license: A `license` block as documented below.
        :param pulumi.Input[str] name: The name of the API Management API. Changing this forces a new resource to be created.
        :param pulumi.Input['ApiOauth2AuthorizationArgs'] oauth2_authorization: An `oauth2_authorization` block as documented below.
        :param pulumi.Input['ApiOpenidAuthenticationArgs'] openid_authentication: An `openid_authentication` block as documented below.
        :param pulumi.Input[str] path: The Path for this API Management API, which is a relative URL which uniquely identifies this API and all of its resource paths within the API Management Service.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] protocols: A list of protocols the operations in this API can be invoked. Possible values are `http`, `https`, `ws`, and `wss`.
               
               > **NOTE:** `display_name`, `path` and `protocols` are required when `source_api_id` is not set.
        :param pulumi.Input[str] revision_description: The description of the API Revision of the API Management API.
        :param pulumi.Input[str] service_url: Absolute URL of the backend service implementing this API.
        :param pulumi.Input[str] source_api_id: The API id of the source API, which could be in format `azurerm_api_management_api.example.id` or in format `azurerm_api_management_api.example.id;rev=1`
        :param pulumi.Input['ApiSubscriptionKeyParameterNamesArgs'] subscription_key_parameter_names: A `subscription_key_parameter_names` block as documented below.
        :param pulumi.Input[bool] subscription_required: Should this API require a subscription key? Defaults to `true`.
        :param pulumi.Input[str] terms_of_service_url: Absolute URL of the Terms of Service for the API.
        :param pulumi.Input[str] version: The Version number of this API, if this API is versioned.
        :param pulumi.Input[str] version_description: The description of the API Version of the API Management API.
        :param pulumi.Input[str] version_set_id: The ID of the Version Set which this API is associated with.
               
               > **NOTE:** When `version` is set, `version_set_id` must also be specified
        """
        pulumi.set(__self__, "api_management_name", api_management_name)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "revision", revision)
        if api_type is not None:
            pulumi.set(__self__, "api_type", api_type)
        if contact is not None:
            pulumi.set(__self__, "contact", contact)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if import_ is not None:
            pulumi.set(__self__, "import_", import_)
        if license is not None:
            pulumi.set(__self__, "license", license)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if oauth2_authorization is not None:
            pulumi.set(__self__, "oauth2_authorization", oauth2_authorization)
        if openid_authentication is not None:
            pulumi.set(__self__, "openid_authentication", openid_authentication)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if protocols is not None:
            pulumi.set(__self__, "protocols", protocols)
        if revision_description is not None:
            pulumi.set(__self__, "revision_description", revision_description)
        if service_url is not None:
            pulumi.set(__self__, "service_url", service_url)
        if source_api_id is not None:
            pulumi.set(__self__, "source_api_id", source_api_id)
        if subscription_key_parameter_names is not None:
            pulumi.set(__self__, "subscription_key_parameter_names", subscription_key_parameter_names)
        if subscription_required is not None:
            pulumi.set(__self__, "subscription_required", subscription_required)
        if terms_of_service_url is not None:
            pulumi.set(__self__, "terms_of_service_url", terms_of_service_url)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if version_description is not None:
            pulumi.set(__self__, "version_description", version_description)
        if version_set_id is not None:
            pulumi.set(__self__, "version_set_id", version_set_id)

    @property
    @pulumi.getter(name="apiManagementName")
    def api_management_name(self) -> pulumi.Input[str]:
        """
        The Name of the API Management Service where this API should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_name")

    @api_management_name.setter
    def api_management_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "api_management_name", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The Name of the Resource Group where the API Management API exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def revision(self) -> pulumi.Input[str]:
        """
        The Revision which used for this API. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "revision")

    @revision.setter
    def revision(self, value: pulumi.Input[str]):
        pulumi.set(self, "revision", value)

    @property
    @pulumi.getter(name="apiType")
    def api_type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of API. Possible values are `graphql`, `http`, `soap`, and `websocket`. Defaults to `http`.
        """
        return pulumi.get(self, "api_type")

    @api_type.setter
    def api_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_type", value)

    @property
    @pulumi.getter
    def contact(self) -> Optional[pulumi.Input['ApiContactArgs']]:
        """
        A `contact` block as documented below.
        """
        return pulumi.get(self, "contact")

    @contact.setter
    def contact(self, value: Optional[pulumi.Input['ApiContactArgs']]):
        pulumi.set(self, "contact", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A description of the API Management API, which may include HTML formatting tags.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The display name of the API.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="import")
    def import_(self) -> Optional[pulumi.Input['ApiImportArgs']]:
        """
        A `import` block as documented below.
        """
        return pulumi.get(self, "import_")

    @import_.setter
    def import_(self, value: Optional[pulumi.Input['ApiImportArgs']]):
        pulumi.set(self, "import_", value)

    @property
    @pulumi.getter
    def license(self) -> Optional[pulumi.Input['ApiLicenseArgs']]:
        """
        A `license` block as documented below.
        """
        return pulumi.get(self, "license")

    @license.setter
    def license(self, value: Optional[pulumi.Input['ApiLicenseArgs']]):
        pulumi.set(self, "license", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the API Management API. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="oauth2Authorization")
    def oauth2_authorization(self) -> Optional[pulumi.Input['ApiOauth2AuthorizationArgs']]:
        """
        An `oauth2_authorization` block as documented below.
        """
        return pulumi.get(self, "oauth2_authorization")

    @oauth2_authorization.setter
    def oauth2_authorization(self, value: Optional[pulumi.Input['ApiOauth2AuthorizationArgs']]):
        pulumi.set(self, "oauth2_authorization", value)

    @property
    @pulumi.getter(name="openidAuthentication")
    def openid_authentication(self) -> Optional[pulumi.Input['ApiOpenidAuthenticationArgs']]:
        """
        An `openid_authentication` block as documented below.
        """
        return pulumi.get(self, "openid_authentication")

    @openid_authentication.setter
    def openid_authentication(self, value: Optional[pulumi.Input['ApiOpenidAuthenticationArgs']]):
        pulumi.set(self, "openid_authentication", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        The Path for this API Management API, which is a relative URL which uniquely identifies this API and all of its resource paths within the API Management Service.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def protocols(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of protocols the operations in this API can be invoked. Possible values are `http`, `https`, `ws`, and `wss`.

        > **NOTE:** `display_name`, `path` and `protocols` are required when `source_api_id` is not set.
        """
        return pulumi.get(self, "protocols")

    @protocols.setter
    def protocols(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "protocols", value)

    @property
    @pulumi.getter(name="revisionDescription")
    def revision_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the API Revision of the API Management API.
        """
        return pulumi.get(self, "revision_description")

    @revision_description.setter
    def revision_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "revision_description", value)

    @property
    @pulumi.getter(name="serviceUrl")
    def service_url(self) -> Optional[pulumi.Input[str]]:
        """
        Absolute URL of the backend service implementing this API.
        """
        return pulumi.get(self, "service_url")

    @service_url.setter
    def service_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_url", value)

    @property
    @pulumi.getter(name="sourceApiId")
    def source_api_id(self) -> Optional[pulumi.Input[str]]:
        """
        The API id of the source API, which could be in format `azurerm_api_management_api.example.id` or in format `azurerm_api_management_api.example.id;rev=1`
        """
        return pulumi.get(self, "source_api_id")

    @source_api_id.setter
    def source_api_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_api_id", value)

    @property
    @pulumi.getter(name="subscriptionKeyParameterNames")
    def subscription_key_parameter_names(self) -> Optional[pulumi.Input['ApiSubscriptionKeyParameterNamesArgs']]:
        """
        A `subscription_key_parameter_names` block as documented below.
        """
        return pulumi.get(self, "subscription_key_parameter_names")

    @subscription_key_parameter_names.setter
    def subscription_key_parameter_names(self, value: Optional[pulumi.Input['ApiSubscriptionKeyParameterNamesArgs']]):
        pulumi.set(self, "subscription_key_parameter_names", value)

    @property
    @pulumi.getter(name="subscriptionRequired")
    def subscription_required(self) -> Optional[pulumi.Input[bool]]:
        """
        Should this API require a subscription key? Defaults to `true`.
        """
        return pulumi.get(self, "subscription_required")

    @subscription_required.setter
    def subscription_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "subscription_required", value)

    @property
    @pulumi.getter(name="termsOfServiceUrl")
    def terms_of_service_url(self) -> Optional[pulumi.Input[str]]:
        """
        Absolute URL of the Terms of Service for the API.
        """
        return pulumi.get(self, "terms_of_service_url")

    @terms_of_service_url.setter
    def terms_of_service_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "terms_of_service_url", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        The Version number of this API, if this API is versioned.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the API Version of the API Management API.
        """
        return pulumi.get(self, "version_description")

    @version_description.setter
    def version_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version_description", value)

    @property
    @pulumi.getter(name="versionSetId")
    def version_set_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Version Set which this API is associated with.

        > **NOTE:** When `version` is set, `version_set_id` must also be specified
        """
        return pulumi.get(self, "version_set_id")

    @version_set_id.setter
    def version_set_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version_set_id", value)


@pulumi.input_type
class _ApiState:
    def __init__(__self__, *,
                 api_management_name: Optional[pulumi.Input[str]] = None,
                 api_type: Optional[pulumi.Input[str]] = None,
                 contact: Optional[pulumi.Input['ApiContactArgs']] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 import_: Optional[pulumi.Input['ApiImportArgs']] = None,
                 is_current: Optional[pulumi.Input[bool]] = None,
                 is_online: Optional[pulumi.Input[bool]] = None,
                 license: Optional[pulumi.Input['ApiLicenseArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 oauth2_authorization: Optional[pulumi.Input['ApiOauth2AuthorizationArgs']] = None,
                 openid_authentication: Optional[pulumi.Input['ApiOpenidAuthenticationArgs']] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 revision: Optional[pulumi.Input[str]] = None,
                 revision_description: Optional[pulumi.Input[str]] = None,
                 service_url: Optional[pulumi.Input[str]] = None,
                 source_api_id: Optional[pulumi.Input[str]] = None,
                 subscription_key_parameter_names: Optional[pulumi.Input['ApiSubscriptionKeyParameterNamesArgs']] = None,
                 subscription_required: Optional[pulumi.Input[bool]] = None,
                 terms_of_service_url: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 version_description: Optional[pulumi.Input[str]] = None,
                 version_set_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Api resources.
        :param pulumi.Input[str] api_management_name: The Name of the API Management Service where this API should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] api_type: Type of API. Possible values are `graphql`, `http`, `soap`, and `websocket`. Defaults to `http`.
        :param pulumi.Input['ApiContactArgs'] contact: A `contact` block as documented below.
        :param pulumi.Input[str] description: A description of the API Management API, which may include HTML formatting tags.
        :param pulumi.Input[str] display_name: The display name of the API.
        :param pulumi.Input['ApiImportArgs'] import_: A `import` block as documented below.
        :param pulumi.Input[bool] is_current: Is this the current API Revision?
        :param pulumi.Input[bool] is_online: Is this API Revision online/accessible via the Gateway?
        :param pulumi.Input['ApiLicenseArgs'] license: A `license` block as documented below.
        :param pulumi.Input[str] name: The name of the API Management API. Changing this forces a new resource to be created.
        :param pulumi.Input['ApiOauth2AuthorizationArgs'] oauth2_authorization: An `oauth2_authorization` block as documented below.
        :param pulumi.Input['ApiOpenidAuthenticationArgs'] openid_authentication: An `openid_authentication` block as documented below.
        :param pulumi.Input[str] path: The Path for this API Management API, which is a relative URL which uniquely identifies this API and all of its resource paths within the API Management Service.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] protocols: A list of protocols the operations in this API can be invoked. Possible values are `http`, `https`, `ws`, and `wss`.
               
               > **NOTE:** `display_name`, `path` and `protocols` are required when `source_api_id` is not set.
        :param pulumi.Input[str] resource_group_name: The Name of the Resource Group where the API Management API exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision: The Revision which used for this API. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision_description: The description of the API Revision of the API Management API.
        :param pulumi.Input[str] service_url: Absolute URL of the backend service implementing this API.
        :param pulumi.Input[str] source_api_id: The API id of the source API, which could be in format `azurerm_api_management_api.example.id` or in format `azurerm_api_management_api.example.id;rev=1`
        :param pulumi.Input['ApiSubscriptionKeyParameterNamesArgs'] subscription_key_parameter_names: A `subscription_key_parameter_names` block as documented below.
        :param pulumi.Input[bool] subscription_required: Should this API require a subscription key? Defaults to `true`.
        :param pulumi.Input[str] terms_of_service_url: Absolute URL of the Terms of Service for the API.
        :param pulumi.Input[str] version: The Version number of this API, if this API is versioned.
        :param pulumi.Input[str] version_description: The description of the API Version of the API Management API.
        :param pulumi.Input[str] version_set_id: The ID of the Version Set which this API is associated with.
               
               > **NOTE:** When `version` is set, `version_set_id` must also be specified
        """
        if api_management_name is not None:
            pulumi.set(__self__, "api_management_name", api_management_name)
        if api_type is not None:
            pulumi.set(__self__, "api_type", api_type)
        if contact is not None:
            pulumi.set(__self__, "contact", contact)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if import_ is not None:
            pulumi.set(__self__, "import_", import_)
        if is_current is not None:
            pulumi.set(__self__, "is_current", is_current)
        if is_online is not None:
            pulumi.set(__self__, "is_online", is_online)
        if license is not None:
            pulumi.set(__self__, "license", license)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if oauth2_authorization is not None:
            pulumi.set(__self__, "oauth2_authorization", oauth2_authorization)
        if openid_authentication is not None:
            pulumi.set(__self__, "openid_authentication", openid_authentication)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if protocols is not None:
            pulumi.set(__self__, "protocols", protocols)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if revision is not None:
            pulumi.set(__self__, "revision", revision)
        if revision_description is not None:
            pulumi.set(__self__, "revision_description", revision_description)
        if service_url is not None:
            pulumi.set(__self__, "service_url", service_url)
        if source_api_id is not None:
            pulumi.set(__self__, "source_api_id", source_api_id)
        if subscription_key_parameter_names is not None:
            pulumi.set(__self__, "subscription_key_parameter_names", subscription_key_parameter_names)
        if subscription_required is not None:
            pulumi.set(__self__, "subscription_required", subscription_required)
        if terms_of_service_url is not None:
            pulumi.set(__self__, "terms_of_service_url", terms_of_service_url)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if version_description is not None:
            pulumi.set(__self__, "version_description", version_description)
        if version_set_id is not None:
            pulumi.set(__self__, "version_set_id", version_set_id)

    @property
    @pulumi.getter(name="apiManagementName")
    def api_management_name(self) -> Optional[pulumi.Input[str]]:
        """
        The Name of the API Management Service where this API should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_name")

    @api_management_name.setter
    def api_management_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_management_name", value)

    @property
    @pulumi.getter(name="apiType")
    def api_type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of API. Possible values are `graphql`, `http`, `soap`, and `websocket`. Defaults to `http`.
        """
        return pulumi.get(self, "api_type")

    @api_type.setter
    def api_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_type", value)

    @property
    @pulumi.getter
    def contact(self) -> Optional[pulumi.Input['ApiContactArgs']]:
        """
        A `contact` block as documented below.
        """
        return pulumi.get(self, "contact")

    @contact.setter
    def contact(self, value: Optional[pulumi.Input['ApiContactArgs']]):
        pulumi.set(self, "contact", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A description of the API Management API, which may include HTML formatting tags.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The display name of the API.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="import")
    def import_(self) -> Optional[pulumi.Input['ApiImportArgs']]:
        """
        A `import` block as documented below.
        """
        return pulumi.get(self, "import_")

    @import_.setter
    def import_(self, value: Optional[pulumi.Input['ApiImportArgs']]):
        pulumi.set(self, "import_", value)

    @property
    @pulumi.getter(name="isCurrent")
    def is_current(self) -> Optional[pulumi.Input[bool]]:
        """
        Is this the current API Revision?
        """
        return pulumi.get(self, "is_current")

    @is_current.setter
    def is_current(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_current", value)

    @property
    @pulumi.getter(name="isOnline")
    def is_online(self) -> Optional[pulumi.Input[bool]]:
        """
        Is this API Revision online/accessible via the Gateway?
        """
        return pulumi.get(self, "is_online")

    @is_online.setter
    def is_online(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_online", value)

    @property
    @pulumi.getter
    def license(self) -> Optional[pulumi.Input['ApiLicenseArgs']]:
        """
        A `license` block as documented below.
        """
        return pulumi.get(self, "license")

    @license.setter
    def license(self, value: Optional[pulumi.Input['ApiLicenseArgs']]):
        pulumi.set(self, "license", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the API Management API. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="oauth2Authorization")
    def oauth2_authorization(self) -> Optional[pulumi.Input['ApiOauth2AuthorizationArgs']]:
        """
        An `oauth2_authorization` block as documented below.
        """
        return pulumi.get(self, "oauth2_authorization")

    @oauth2_authorization.setter
    def oauth2_authorization(self, value: Optional[pulumi.Input['ApiOauth2AuthorizationArgs']]):
        pulumi.set(self, "oauth2_authorization", value)

    @property
    @pulumi.getter(name="openidAuthentication")
    def openid_authentication(self) -> Optional[pulumi.Input['ApiOpenidAuthenticationArgs']]:
        """
        An `openid_authentication` block as documented below.
        """
        return pulumi.get(self, "openid_authentication")

    @openid_authentication.setter
    def openid_authentication(self, value: Optional[pulumi.Input['ApiOpenidAuthenticationArgs']]):
        pulumi.set(self, "openid_authentication", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        The Path for this API Management API, which is a relative URL which uniquely identifies this API and all of its resource paths within the API Management Service.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def protocols(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of protocols the operations in this API can be invoked. Possible values are `http`, `https`, `ws`, and `wss`.

        > **NOTE:** `display_name`, `path` and `protocols` are required when `source_api_id` is not set.
        """
        return pulumi.get(self, "protocols")

    @protocols.setter
    def protocols(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "protocols", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The Name of the Resource Group where the API Management API exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def revision(self) -> Optional[pulumi.Input[str]]:
        """
        The Revision which used for this API. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "revision")

    @revision.setter
    def revision(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "revision", value)

    @property
    @pulumi.getter(name="revisionDescription")
    def revision_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the API Revision of the API Management API.
        """
        return pulumi.get(self, "revision_description")

    @revision_description.setter
    def revision_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "revision_description", value)

    @property
    @pulumi.getter(name="serviceUrl")
    def service_url(self) -> Optional[pulumi.Input[str]]:
        """
        Absolute URL of the backend service implementing this API.
        """
        return pulumi.get(self, "service_url")

    @service_url.setter
    def service_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_url", value)

    @property
    @pulumi.getter(name="sourceApiId")
    def source_api_id(self) -> Optional[pulumi.Input[str]]:
        """
        The API id of the source API, which could be in format `azurerm_api_management_api.example.id` or in format `azurerm_api_management_api.example.id;rev=1`
        """
        return pulumi.get(self, "source_api_id")

    @source_api_id.setter
    def source_api_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_api_id", value)

    @property
    @pulumi.getter(name="subscriptionKeyParameterNames")
    def subscription_key_parameter_names(self) -> Optional[pulumi.Input['ApiSubscriptionKeyParameterNamesArgs']]:
        """
        A `subscription_key_parameter_names` block as documented below.
        """
        return pulumi.get(self, "subscription_key_parameter_names")

    @subscription_key_parameter_names.setter
    def subscription_key_parameter_names(self, value: Optional[pulumi.Input['ApiSubscriptionKeyParameterNamesArgs']]):
        pulumi.set(self, "subscription_key_parameter_names", value)

    @property
    @pulumi.getter(name="subscriptionRequired")
    def subscription_required(self) -> Optional[pulumi.Input[bool]]:
        """
        Should this API require a subscription key? Defaults to `true`.
        """
        return pulumi.get(self, "subscription_required")

    @subscription_required.setter
    def subscription_required(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "subscription_required", value)

    @property
    @pulumi.getter(name="termsOfServiceUrl")
    def terms_of_service_url(self) -> Optional[pulumi.Input[str]]:
        """
        Absolute URL of the Terms of Service for the API.
        """
        return pulumi.get(self, "terms_of_service_url")

    @terms_of_service_url.setter
    def terms_of_service_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "terms_of_service_url", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        The Version number of this API, if this API is versioned.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the API Version of the API Management API.
        """
        return pulumi.get(self, "version_description")

    @version_description.setter
    def version_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version_description", value)

    @property
    @pulumi.getter(name="versionSetId")
    def version_set_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Version Set which this API is associated with.

        > **NOTE:** When `version` is set, `version_set_id` must also be specified
        """
        return pulumi.get(self, "version_set_id")

    @version_set_id.setter
    def version_set_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version_set_id", value)


class Api(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_management_name: Optional[pulumi.Input[str]] = None,
                 api_type: Optional[pulumi.Input[str]] = None,
                 contact: Optional[pulumi.Input[Union['ApiContactArgs', 'ApiContactArgsDict']]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 import_: Optional[pulumi.Input[Union['ApiImportArgs', 'ApiImportArgsDict']]] = None,
                 license: Optional[pulumi.Input[Union['ApiLicenseArgs', 'ApiLicenseArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 oauth2_authorization: Optional[pulumi.Input[Union['ApiOauth2AuthorizationArgs', 'ApiOauth2AuthorizationArgsDict']]] = None,
                 openid_authentication: Optional[pulumi.Input[Union['ApiOpenidAuthenticationArgs', 'ApiOpenidAuthenticationArgsDict']]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 revision: Optional[pulumi.Input[str]] = None,
                 revision_description: Optional[pulumi.Input[str]] = None,
                 service_url: Optional[pulumi.Input[str]] = None,
                 source_api_id: Optional[pulumi.Input[str]] = None,
                 subscription_key_parameter_names: Optional[pulumi.Input[Union['ApiSubscriptionKeyParameterNamesArgs', 'ApiSubscriptionKeyParameterNamesArgsDict']]] = None,
                 subscription_required: Optional[pulumi.Input[bool]] = None,
                 terms_of_service_url: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 version_description: Optional[pulumi.Input[str]] = None,
                 version_set_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages an API within an API Management Service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_service = azure.apimanagement.Service("example",
            name="example-apim",
            location=example.location,
            resource_group_name=example.name,
            publisher_name="My Company",
            publisher_email="company@exmaple.com",
            sku_name="Developer_1")
        example_api = azure.apimanagement.Api("example",
            name="example-api",
            resource_group_name=example.name,
            api_management_name=example_service.name,
            revision="1",
            display_name="Example API",
            path="example",
            protocols=["https"],
            import_={
                "content_format": "swagger-link-json",
                "content_value": "https://raw.githubusercontent.com/hashicorp/terraform-provider-azurerm/refs/heads/main/internal/services/apimanagement/testdata/api_management_api_schema_swagger.json",
            })
        ```

        ## Import

        API Management API's can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/api:Api example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.ApiManagement/service/instance1/apis/api1;rev=1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_management_name: The Name of the API Management Service where this API should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] api_type: Type of API. Possible values are `graphql`, `http`, `soap`, and `websocket`. Defaults to `http`.
        :param pulumi.Input[Union['ApiContactArgs', 'ApiContactArgsDict']] contact: A `contact` block as documented below.
        :param pulumi.Input[str] description: A description of the API Management API, which may include HTML formatting tags.
        :param pulumi.Input[str] display_name: The display name of the API.
        :param pulumi.Input[Union['ApiImportArgs', 'ApiImportArgsDict']] import_: A `import` block as documented below.
        :param pulumi.Input[Union['ApiLicenseArgs', 'ApiLicenseArgsDict']] license: A `license` block as documented below.
        :param pulumi.Input[str] name: The name of the API Management API. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ApiOauth2AuthorizationArgs', 'ApiOauth2AuthorizationArgsDict']] oauth2_authorization: An `oauth2_authorization` block as documented below.
        :param pulumi.Input[Union['ApiOpenidAuthenticationArgs', 'ApiOpenidAuthenticationArgsDict']] openid_authentication: An `openid_authentication` block as documented below.
        :param pulumi.Input[str] path: The Path for this API Management API, which is a relative URL which uniquely identifies this API and all of its resource paths within the API Management Service.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] protocols: A list of protocols the operations in this API can be invoked. Possible values are `http`, `https`, `ws`, and `wss`.
               
               > **NOTE:** `display_name`, `path` and `protocols` are required when `source_api_id` is not set.
        :param pulumi.Input[str] resource_group_name: The Name of the Resource Group where the API Management API exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision: The Revision which used for this API. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision_description: The description of the API Revision of the API Management API.
        :param pulumi.Input[str] service_url: Absolute URL of the backend service implementing this API.
        :param pulumi.Input[str] source_api_id: The API id of the source API, which could be in format `azurerm_api_management_api.example.id` or in format `azurerm_api_management_api.example.id;rev=1`
        :param pulumi.Input[Union['ApiSubscriptionKeyParameterNamesArgs', 'ApiSubscriptionKeyParameterNamesArgsDict']] subscription_key_parameter_names: A `subscription_key_parameter_names` block as documented below.
        :param pulumi.Input[bool] subscription_required: Should this API require a subscription key? Defaults to `true`.
        :param pulumi.Input[str] terms_of_service_url: Absolute URL of the Terms of Service for the API.
        :param pulumi.Input[str] version: The Version number of this API, if this API is versioned.
        :param pulumi.Input[str] version_description: The description of the API Version of the API Management API.
        :param pulumi.Input[str] version_set_id: The ID of the Version Set which this API is associated with.
               
               > **NOTE:** When `version` is set, `version_set_id` must also be specified
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApiArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an API within an API Management Service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_service = azure.apimanagement.Service("example",
            name="example-apim",
            location=example.location,
            resource_group_name=example.name,
            publisher_name="My Company",
            publisher_email="company@exmaple.com",
            sku_name="Developer_1")
        example_api = azure.apimanagement.Api("example",
            name="example-api",
            resource_group_name=example.name,
            api_management_name=example_service.name,
            revision="1",
            display_name="Example API",
            path="example",
            protocols=["https"],
            import_={
                "content_format": "swagger-link-json",
                "content_value": "https://raw.githubusercontent.com/hashicorp/terraform-provider-azurerm/refs/heads/main/internal/services/apimanagement/testdata/api_management_api_schema_swagger.json",
            })
        ```

        ## Import

        API Management API's can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/api:Api example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.ApiManagement/service/instance1/apis/api1;rev=1
        ```

        :param str resource_name: The name of the resource.
        :param ApiArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_management_name: Optional[pulumi.Input[str]] = None,
                 api_type: Optional[pulumi.Input[str]] = None,
                 contact: Optional[pulumi.Input[Union['ApiContactArgs', 'ApiContactArgsDict']]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 import_: Optional[pulumi.Input[Union['ApiImportArgs', 'ApiImportArgsDict']]] = None,
                 license: Optional[pulumi.Input[Union['ApiLicenseArgs', 'ApiLicenseArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 oauth2_authorization: Optional[pulumi.Input[Union['ApiOauth2AuthorizationArgs', 'ApiOauth2AuthorizationArgsDict']]] = None,
                 openid_authentication: Optional[pulumi.Input[Union['ApiOpenidAuthenticationArgs', 'ApiOpenidAuthenticationArgsDict']]] = None,
                 path: Optional[pulumi.Input[str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 revision: Optional[pulumi.Input[str]] = None,
                 revision_description: Optional[pulumi.Input[str]] = None,
                 service_url: Optional[pulumi.Input[str]] = None,
                 source_api_id: Optional[pulumi.Input[str]] = None,
                 subscription_key_parameter_names: Optional[pulumi.Input[Union['ApiSubscriptionKeyParameterNamesArgs', 'ApiSubscriptionKeyParameterNamesArgsDict']]] = None,
                 subscription_required: Optional[pulumi.Input[bool]] = None,
                 terms_of_service_url: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 version_description: Optional[pulumi.Input[str]] = None,
                 version_set_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiArgs.__new__(ApiArgs)

            if api_management_name is None and not opts.urn:
                raise TypeError("Missing required property 'api_management_name'")
            __props__.__dict__["api_management_name"] = api_management_name
            __props__.__dict__["api_type"] = api_type
            __props__.__dict__["contact"] = contact
            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["import_"] = import_
            __props__.__dict__["license"] = license
            __props__.__dict__["name"] = name
            __props__.__dict__["oauth2_authorization"] = oauth2_authorization
            __props__.__dict__["openid_authentication"] = openid_authentication
            __props__.__dict__["path"] = path
            __props__.__dict__["protocols"] = protocols
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if revision is None and not opts.urn:
                raise TypeError("Missing required property 'revision'")
            __props__.__dict__["revision"] = revision
            __props__.__dict__["revision_description"] = revision_description
            __props__.__dict__["service_url"] = service_url
            __props__.__dict__["source_api_id"] = source_api_id
            __props__.__dict__["subscription_key_parameter_names"] = subscription_key_parameter_names
            __props__.__dict__["subscription_required"] = subscription_required
            __props__.__dict__["terms_of_service_url"] = terms_of_service_url
            __props__.__dict__["version"] = version
            __props__.__dict__["version_description"] = version_description
            __props__.__dict__["version_set_id"] = version_set_id
            __props__.__dict__["is_current"] = None
            __props__.__dict__["is_online"] = None
        super(Api, __self__).__init__(
            'azure:apimanagement/api:Api',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_management_name: Optional[pulumi.Input[str]] = None,
            api_type: Optional[pulumi.Input[str]] = None,
            contact: Optional[pulumi.Input[Union['ApiContactArgs', 'ApiContactArgsDict']]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            import_: Optional[pulumi.Input[Union['ApiImportArgs', 'ApiImportArgsDict']]] = None,
            is_current: Optional[pulumi.Input[bool]] = None,
            is_online: Optional[pulumi.Input[bool]] = None,
            license: Optional[pulumi.Input[Union['ApiLicenseArgs', 'ApiLicenseArgsDict']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            oauth2_authorization: Optional[pulumi.Input[Union['ApiOauth2AuthorizationArgs', 'ApiOauth2AuthorizationArgsDict']]] = None,
            openid_authentication: Optional[pulumi.Input[Union['ApiOpenidAuthenticationArgs', 'ApiOpenidAuthenticationArgsDict']]] = None,
            path: Optional[pulumi.Input[str]] = None,
            protocols: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            revision: Optional[pulumi.Input[str]] = None,
            revision_description: Optional[pulumi.Input[str]] = None,
            service_url: Optional[pulumi.Input[str]] = None,
            source_api_id: Optional[pulumi.Input[str]] = None,
            subscription_key_parameter_names: Optional[pulumi.Input[Union['ApiSubscriptionKeyParameterNamesArgs', 'ApiSubscriptionKeyParameterNamesArgsDict']]] = None,
            subscription_required: Optional[pulumi.Input[bool]] = None,
            terms_of_service_url: Optional[pulumi.Input[str]] = None,
            version: Optional[pulumi.Input[str]] = None,
            version_description: Optional[pulumi.Input[str]] = None,
            version_set_id: Optional[pulumi.Input[str]] = None) -> 'Api':
        """
        Get an existing Api resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_management_name: The Name of the API Management Service where this API should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] api_type: Type of API. Possible values are `graphql`, `http`, `soap`, and `websocket`. Defaults to `http`.
        :param pulumi.Input[Union['ApiContactArgs', 'ApiContactArgsDict']] contact: A `contact` block as documented below.
        :param pulumi.Input[str] description: A description of the API Management API, which may include HTML formatting tags.
        :param pulumi.Input[str] display_name: The display name of the API.
        :param pulumi.Input[Union['ApiImportArgs', 'ApiImportArgsDict']] import_: A `import` block as documented below.
        :param pulumi.Input[bool] is_current: Is this the current API Revision?
        :param pulumi.Input[bool] is_online: Is this API Revision online/accessible via the Gateway?
        :param pulumi.Input[Union['ApiLicenseArgs', 'ApiLicenseArgsDict']] license: A `license` block as documented below.
        :param pulumi.Input[str] name: The name of the API Management API. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ApiOauth2AuthorizationArgs', 'ApiOauth2AuthorizationArgsDict']] oauth2_authorization: An `oauth2_authorization` block as documented below.
        :param pulumi.Input[Union['ApiOpenidAuthenticationArgs', 'ApiOpenidAuthenticationArgsDict']] openid_authentication: An `openid_authentication` block as documented below.
        :param pulumi.Input[str] path: The Path for this API Management API, which is a relative URL which uniquely identifies this API and all of its resource paths within the API Management Service.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] protocols: A list of protocols the operations in this API can be invoked. Possible values are `http`, `https`, `ws`, and `wss`.
               
               > **NOTE:** `display_name`, `path` and `protocols` are required when `source_api_id` is not set.
        :param pulumi.Input[str] resource_group_name: The Name of the Resource Group where the API Management API exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision: The Revision which used for this API. Changing this forces a new resource to be created.
        :param pulumi.Input[str] revision_description: The description of the API Revision of the API Management API.
        :param pulumi.Input[str] service_url: Absolute URL of the backend service implementing this API.
        :param pulumi.Input[str] source_api_id: The API id of the source API, which could be in format `azurerm_api_management_api.example.id` or in format `azurerm_api_management_api.example.id;rev=1`
        :param pulumi.Input[Union['ApiSubscriptionKeyParameterNamesArgs', 'ApiSubscriptionKeyParameterNamesArgsDict']] subscription_key_parameter_names: A `subscription_key_parameter_names` block as documented below.
        :param pulumi.Input[bool] subscription_required: Should this API require a subscription key? Defaults to `true`.
        :param pulumi.Input[str] terms_of_service_url: Absolute URL of the Terms of Service for the API.
        :param pulumi.Input[str] version: The Version number of this API, if this API is versioned.
        :param pulumi.Input[str] version_description: The description of the API Version of the API Management API.
        :param pulumi.Input[str] version_set_id: The ID of the Version Set which this API is associated with.
               
               > **NOTE:** When `version` is set, `version_set_id` must also be specified
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiState.__new__(_ApiState)

        __props__.__dict__["api_management_name"] = api_management_name
        __props__.__dict__["api_type"] = api_type
        __props__.__dict__["contact"] = contact
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["import_"] = import_
        __props__.__dict__["is_current"] = is_current
        __props__.__dict__["is_online"] = is_online
        __props__.__dict__["license"] = license
        __props__.__dict__["name"] = name
        __props__.__dict__["oauth2_authorization"] = oauth2_authorization
        __props__.__dict__["openid_authentication"] = openid_authentication
        __props__.__dict__["path"] = path
        __props__.__dict__["protocols"] = protocols
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["revision"] = revision
        __props__.__dict__["revision_description"] = revision_description
        __props__.__dict__["service_url"] = service_url
        __props__.__dict__["source_api_id"] = source_api_id
        __props__.__dict__["subscription_key_parameter_names"] = subscription_key_parameter_names
        __props__.__dict__["subscription_required"] = subscription_required
        __props__.__dict__["terms_of_service_url"] = terms_of_service_url
        __props__.__dict__["version"] = version
        __props__.__dict__["version_description"] = version_description
        __props__.__dict__["version_set_id"] = version_set_id
        return Api(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="apiManagementName")
    def api_management_name(self) -> pulumi.Output[str]:
        """
        The Name of the API Management Service where this API should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_name")

    @property
    @pulumi.getter(name="apiType")
    def api_type(self) -> pulumi.Output[str]:
        """
        Type of API. Possible values are `graphql`, `http`, `soap`, and `websocket`. Defaults to `http`.
        """
        return pulumi.get(self, "api_type")

    @property
    @pulumi.getter
    def contact(self) -> pulumi.Output[Optional['outputs.ApiContact']]:
        """
        A `contact` block as documented below.
        """
        return pulumi.get(self, "contact")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A description of the API Management API, which may include HTML formatting tags.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        The display name of the API.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="import")
    def import_(self) -> pulumi.Output[Optional['outputs.ApiImport']]:
        """
        A `import` block as documented below.
        """
        return pulumi.get(self, "import_")

    @property
    @pulumi.getter(name="isCurrent")
    def is_current(self) -> pulumi.Output[bool]:
        """
        Is this the current API Revision?
        """
        return pulumi.get(self, "is_current")

    @property
    @pulumi.getter(name="isOnline")
    def is_online(self) -> pulumi.Output[bool]:
        """
        Is this API Revision online/accessible via the Gateway?
        """
        return pulumi.get(self, "is_online")

    @property
    @pulumi.getter
    def license(self) -> pulumi.Output[Optional['outputs.ApiLicense']]:
        """
        A `license` block as documented below.
        """
        return pulumi.get(self, "license")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the API Management API. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="oauth2Authorization")
    def oauth2_authorization(self) -> pulumi.Output[Optional['outputs.ApiOauth2Authorization']]:
        """
        An `oauth2_authorization` block as documented below.
        """
        return pulumi.get(self, "oauth2_authorization")

    @property
    @pulumi.getter(name="openidAuthentication")
    def openid_authentication(self) -> pulumi.Output[Optional['outputs.ApiOpenidAuthentication']]:
        """
        An `openid_authentication` block as documented below.
        """
        return pulumi.get(self, "openid_authentication")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[str]:
        """
        The Path for this API Management API, which is a relative URL which uniquely identifies this API and all of its resource paths within the API Management Service.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def protocols(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of protocols the operations in this API can be invoked. Possible values are `http`, `https`, `ws`, and `wss`.

        > **NOTE:** `display_name`, `path` and `protocols` are required when `source_api_id` is not set.
        """
        return pulumi.get(self, "protocols")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The Name of the Resource Group where the API Management API exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def revision(self) -> pulumi.Output[str]:
        """
        The Revision which used for this API. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "revision")

    @property
    @pulumi.getter(name="revisionDescription")
    def revision_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the API Revision of the API Management API.
        """
        return pulumi.get(self, "revision_description")

    @property
    @pulumi.getter(name="serviceUrl")
    def service_url(self) -> pulumi.Output[str]:
        """
        Absolute URL of the backend service implementing this API.
        """
        return pulumi.get(self, "service_url")

    @property
    @pulumi.getter(name="sourceApiId")
    def source_api_id(self) -> pulumi.Output[Optional[str]]:
        """
        The API id of the source API, which could be in format `azurerm_api_management_api.example.id` or in format `azurerm_api_management_api.example.id;rev=1`
        """
        return pulumi.get(self, "source_api_id")

    @property
    @pulumi.getter(name="subscriptionKeyParameterNames")
    def subscription_key_parameter_names(self) -> pulumi.Output['outputs.ApiSubscriptionKeyParameterNames']:
        """
        A `subscription_key_parameter_names` block as documented below.
        """
        return pulumi.get(self, "subscription_key_parameter_names")

    @property
    @pulumi.getter(name="subscriptionRequired")
    def subscription_required(self) -> pulumi.Output[Optional[bool]]:
        """
        Should this API require a subscription key? Defaults to `true`.
        """
        return pulumi.get(self, "subscription_required")

    @property
    @pulumi.getter(name="termsOfServiceUrl")
    def terms_of_service_url(self) -> pulumi.Output[Optional[str]]:
        """
        Absolute URL of the Terms of Service for the API.
        """
        return pulumi.get(self, "terms_of_service_url")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[str]:
        """
        The Version number of this API, if this API is versioned.
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the API Version of the API Management API.
        """
        return pulumi.get(self, "version_description")

    @property
    @pulumi.getter(name="versionSetId")
    def version_set_id(self) -> pulumi.Output[str]:
        """
        The ID of the Version Set which this API is associated with.

        > **NOTE:** When `version` is set, `version_set_id` must also be specified
        """
        return pulumi.get(self, "version_set_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TagRulesArgs', 'TagRules']

@pulumi.input_type
class TagRulesArgs:
    def __init__(__self__, *,
                 monitor_id: pulumi.Input[str],
                 log_rule: Optional[pulumi.Input['TagRulesLogRuleArgs']] = None,
                 metric_rule: Optional[pulumi.Input['TagRulesMetricRuleArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a TagRules resource.
        :param pulumi.Input[str] monitor_id: Name of the Dynatrace monitor. Changing this forces a new resource to be created.
        :param pulumi.Input['TagRulesLogRuleArgs'] log_rule: Set of rules for sending logs for the Monitor resource. Changing this forces a new resource to be created. A `log_rule` block as defined below.
        :param pulumi.Input['TagRulesMetricRuleArgs'] metric_rule: Set of rules for sending metrics for the Monitor resource. Changing this forces a new resource to be created. A `metric_rule` block as defined below.
        :param pulumi.Input[str] name: Name of the Dynatrace tag rules. Currently, the only supported value is `default`. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "monitor_id", monitor_id)
        if log_rule is not None:
            pulumi.set(__self__, "log_rule", log_rule)
        if metric_rule is not None:
            pulumi.set(__self__, "metric_rule", metric_rule)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="monitorId")
    def monitor_id(self) -> pulumi.Input[str]:
        """
        Name of the Dynatrace monitor. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "monitor_id")

    @monitor_id.setter
    def monitor_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "monitor_id", value)

    @property
    @pulumi.getter(name="logRule")
    def log_rule(self) -> Optional[pulumi.Input['TagRulesLogRuleArgs']]:
        """
        Set of rules for sending logs for the Monitor resource. Changing this forces a new resource to be created. A `log_rule` block as defined below.
        """
        return pulumi.get(self, "log_rule")

    @log_rule.setter
    def log_rule(self, value: Optional[pulumi.Input['TagRulesLogRuleArgs']]):
        pulumi.set(self, "log_rule", value)

    @property
    @pulumi.getter(name="metricRule")
    def metric_rule(self) -> Optional[pulumi.Input['TagRulesMetricRuleArgs']]:
        """
        Set of rules for sending metrics for the Monitor resource. Changing this forces a new resource to be created. A `metric_rule` block as defined below.
        """
        return pulumi.get(self, "metric_rule")

    @metric_rule.setter
    def metric_rule(self, value: Optional[pulumi.Input['TagRulesMetricRuleArgs']]):
        pulumi.set(self, "metric_rule", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Dynatrace tag rules. Currently, the only supported value is `default`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _TagRulesState:
    def __init__(__self__, *,
                 log_rule: Optional[pulumi.Input['TagRulesLogRuleArgs']] = None,
                 metric_rule: Optional[pulumi.Input['TagRulesMetricRuleArgs']] = None,
                 monitor_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering TagRules resources.
        :param pulumi.Input['TagRulesLogRuleArgs'] log_rule: Set of rules for sending logs for the Monitor resource. Changing this forces a new resource to be created. A `log_rule` block as defined below.
        :param pulumi.Input['TagRulesMetricRuleArgs'] metric_rule: Set of rules for sending metrics for the Monitor resource. Changing this forces a new resource to be created. A `metric_rule` block as defined below.
        :param pulumi.Input[str] monitor_id: Name of the Dynatrace monitor. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Name of the Dynatrace tag rules. Currently, the only supported value is `default`. Changing this forces a new resource to be created.
        """
        if log_rule is not None:
            pulumi.set(__self__, "log_rule", log_rule)
        if metric_rule is not None:
            pulumi.set(__self__, "metric_rule", metric_rule)
        if monitor_id is not None:
            pulumi.set(__self__, "monitor_id", monitor_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="logRule")
    def log_rule(self) -> Optional[pulumi.Input['TagRulesLogRuleArgs']]:
        """
        Set of rules for sending logs for the Monitor resource. Changing this forces a new resource to be created. A `log_rule` block as defined below.
        """
        return pulumi.get(self, "log_rule")

    @log_rule.setter
    def log_rule(self, value: Optional[pulumi.Input['TagRulesLogRuleArgs']]):
        pulumi.set(self, "log_rule", value)

    @property
    @pulumi.getter(name="metricRule")
    def metric_rule(self) -> Optional[pulumi.Input['TagRulesMetricRuleArgs']]:
        """
        Set of rules for sending metrics for the Monitor resource. Changing this forces a new resource to be created. A `metric_rule` block as defined below.
        """
        return pulumi.get(self, "metric_rule")

    @metric_rule.setter
    def metric_rule(self, value: Optional[pulumi.Input['TagRulesMetricRuleArgs']]):
        pulumi.set(self, "metric_rule", value)

    @property
    @pulumi.getter(name="monitorId")
    def monitor_id(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Dynatrace monitor. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "monitor_id")

    @monitor_id.setter
    def monitor_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitor_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Dynatrace tag rules. Currently, the only supported value is `default`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class TagRules(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 log_rule: Optional[pulumi.Input[Union['TagRulesLogRuleArgs', 'TagRulesLogRuleArgsDict']]] = None,
                 metric_rule: Optional[pulumi.Input[Union['TagRulesMetricRuleArgs', 'TagRulesMetricRuleArgsDict']]] = None,
                 monitor_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages Dynatrace tag rules.

        ## Import

        Dynatrace tag rules can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:dynatrace/tagRules:TagRules example /subscriptions/12345678-1234-9876-4563-123456789012/resourceGroups/resGroup1/providers/Dynatrace.Observability/monitors/monitor1/tagRules/tagRules1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['TagRulesLogRuleArgs', 'TagRulesLogRuleArgsDict']] log_rule: Set of rules for sending logs for the Monitor resource. Changing this forces a new resource to be created. A `log_rule` block as defined below.
        :param pulumi.Input[Union['TagRulesMetricRuleArgs', 'TagRulesMetricRuleArgsDict']] metric_rule: Set of rules for sending metrics for the Monitor resource. Changing this forces a new resource to be created. A `metric_rule` block as defined below.
        :param pulumi.Input[str] monitor_id: Name of the Dynatrace monitor. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Name of the Dynatrace tag rules. Currently, the only supported value is `default`. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TagRulesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Dynatrace tag rules.

        ## Import

        Dynatrace tag rules can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:dynatrace/tagRules:TagRules example /subscriptions/12345678-1234-9876-4563-123456789012/resourceGroups/resGroup1/providers/Dynatrace.Observability/monitors/monitor1/tagRules/tagRules1
        ```

        :param str resource_name: The name of the resource.
        :param TagRulesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TagRulesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 log_rule: Optional[pulumi.Input[Union['TagRulesLogRuleArgs', 'TagRulesLogRuleArgsDict']]] = None,
                 metric_rule: Optional[pulumi.Input[Union['TagRulesMetricRuleArgs', 'TagRulesMetricRuleArgsDict']]] = None,
                 monitor_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TagRulesArgs.__new__(TagRulesArgs)

            __props__.__dict__["log_rule"] = log_rule
            __props__.__dict__["metric_rule"] = metric_rule
            if monitor_id is None and not opts.urn:
                raise TypeError("Missing required property 'monitor_id'")
            __props__.__dict__["monitor_id"] = monitor_id
            __props__.__dict__["name"] = name
        super(TagRules, __self__).__init__(
            'azure:dynatrace/tagRules:TagRules',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            log_rule: Optional[pulumi.Input[Union['TagRulesLogRuleArgs', 'TagRulesLogRuleArgsDict']]] = None,
            metric_rule: Optional[pulumi.Input[Union['TagRulesMetricRuleArgs', 'TagRulesMetricRuleArgsDict']]] = None,
            monitor_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'TagRules':
        """
        Get an existing TagRules resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['TagRulesLogRuleArgs', 'TagRulesLogRuleArgsDict']] log_rule: Set of rules for sending logs for the Monitor resource. Changing this forces a new resource to be created. A `log_rule` block as defined below.
        :param pulumi.Input[Union['TagRulesMetricRuleArgs', 'TagRulesMetricRuleArgsDict']] metric_rule: Set of rules for sending metrics for the Monitor resource. Changing this forces a new resource to be created. A `metric_rule` block as defined below.
        :param pulumi.Input[str] monitor_id: Name of the Dynatrace monitor. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Name of the Dynatrace tag rules. Currently, the only supported value is `default`. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TagRulesState.__new__(_TagRulesState)

        __props__.__dict__["log_rule"] = log_rule
        __props__.__dict__["metric_rule"] = metric_rule
        __props__.__dict__["monitor_id"] = monitor_id
        __props__.__dict__["name"] = name
        return TagRules(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="logRule")
    def log_rule(self) -> pulumi.Output[Optional['outputs.TagRulesLogRule']]:
        """
        Set of rules for sending logs for the Monitor resource. Changing this forces a new resource to be created. A `log_rule` block as defined below.
        """
        return pulumi.get(self, "log_rule")

    @property
    @pulumi.getter(name="metricRule")
    def metric_rule(self) -> pulumi.Output[Optional['outputs.TagRulesMetricRule']]:
        """
        Set of rules for sending metrics for the Monitor resource. Changing this forces a new resource to be created. A `metric_rule` block as defined below.
        """
        return pulumi.get(self, "metric_rule")

    @property
    @pulumi.getter(name="monitorId")
    def monitor_id(self) -> pulumi.Output[str]:
        """
        Name of the Dynatrace monitor. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "monitor_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the Dynatrace tag rules. Currently, the only supported value is `default`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetApplicationGatewayResult',
    'AwaitableGetApplicationGatewayResult',
    'get_application_gateway',
    'get_application_gateway_output',
]

@pulumi.output_type
class GetApplicationGatewayResult:
    """
    A collection of values returned by getApplicationGateway.
    """
    def __init__(__self__, authentication_certificates=None, autoscale_configurations=None, backend_address_pools=None, backend_http_settings=None, custom_error_configurations=None, fips_enabled=None, firewall_policy_id=None, force_firewall_policy_association=None, frontend_ip_configurations=None, frontend_ports=None, gateway_ip_configurations=None, globals=None, http2_enabled=None, http_listeners=None, id=None, identities=None, location=None, name=None, private_endpoint_connections=None, private_link_configurations=None, probes=None, redirect_configurations=None, request_routing_rules=None, resource_group_name=None, rewrite_rule_sets=None, skus=None, ssl_certificates=None, ssl_policies=None, ssl_profiles=None, tags=None, trusted_client_certificates=None, trusted_root_certificates=None, url_path_maps=None, waf_configurations=None, zones=None):
        if authentication_certificates and not isinstance(authentication_certificates, list):
            raise TypeError("Expected argument 'authentication_certificates' to be a list")
        pulumi.set(__self__, "authentication_certificates", authentication_certificates)
        if autoscale_configurations and not isinstance(autoscale_configurations, list):
            raise TypeError("Expected argument 'autoscale_configurations' to be a list")
        pulumi.set(__self__, "autoscale_configurations", autoscale_configurations)
        if backend_address_pools and not isinstance(backend_address_pools, list):
            raise TypeError("Expected argument 'backend_address_pools' to be a list")
        pulumi.set(__self__, "backend_address_pools", backend_address_pools)
        if backend_http_settings and not isinstance(backend_http_settings, list):
            raise TypeError("Expected argument 'backend_http_settings' to be a list")
        pulumi.set(__self__, "backend_http_settings", backend_http_settings)
        if custom_error_configurations and not isinstance(custom_error_configurations, list):
            raise TypeError("Expected argument 'custom_error_configurations' to be a list")
        pulumi.set(__self__, "custom_error_configurations", custom_error_configurations)
        if fips_enabled and not isinstance(fips_enabled, bool):
            raise TypeError("Expected argument 'fips_enabled' to be a bool")
        pulumi.set(__self__, "fips_enabled", fips_enabled)
        if firewall_policy_id and not isinstance(firewall_policy_id, str):
            raise TypeError("Expected argument 'firewall_policy_id' to be a str")
        pulumi.set(__self__, "firewall_policy_id", firewall_policy_id)
        if force_firewall_policy_association and not isinstance(force_firewall_policy_association, bool):
            raise TypeError("Expected argument 'force_firewall_policy_association' to be a bool")
        pulumi.set(__self__, "force_firewall_policy_association", force_firewall_policy_association)
        if frontend_ip_configurations and not isinstance(frontend_ip_configurations, list):
            raise TypeError("Expected argument 'frontend_ip_configurations' to be a list")
        pulumi.set(__self__, "frontend_ip_configurations", frontend_ip_configurations)
        if frontend_ports and not isinstance(frontend_ports, list):
            raise TypeError("Expected argument 'frontend_ports' to be a list")
        pulumi.set(__self__, "frontend_ports", frontend_ports)
        if gateway_ip_configurations and not isinstance(gateway_ip_configurations, list):
            raise TypeError("Expected argument 'gateway_ip_configurations' to be a list")
        pulumi.set(__self__, "gateway_ip_configurations", gateway_ip_configurations)
        if globals and not isinstance(globals, list):
            raise TypeError("Expected argument 'globals' to be a list")
        pulumi.set(__self__, "globals", globals)
        if http2_enabled and not isinstance(http2_enabled, bool):
            raise TypeError("Expected argument 'http2_enabled' to be a bool")
        pulumi.set(__self__, "http2_enabled", http2_enabled)
        if http_listeners and not isinstance(http_listeners, list):
            raise TypeError("Expected argument 'http_listeners' to be a list")
        pulumi.set(__self__, "http_listeners", http_listeners)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identities and not isinstance(identities, list):
            raise TypeError("Expected argument 'identities' to be a list")
        pulumi.set(__self__, "identities", identities)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if private_endpoint_connections and not isinstance(private_endpoint_connections, list):
            raise TypeError("Expected argument 'private_endpoint_connections' to be a list")
        pulumi.set(__self__, "private_endpoint_connections", private_endpoint_connections)
        if private_link_configurations and not isinstance(private_link_configurations, list):
            raise TypeError("Expected argument 'private_link_configurations' to be a list")
        pulumi.set(__self__, "private_link_configurations", private_link_configurations)
        if probes and not isinstance(probes, list):
            raise TypeError("Expected argument 'probes' to be a list")
        pulumi.set(__self__, "probes", probes)
        if redirect_configurations and not isinstance(redirect_configurations, list):
            raise TypeError("Expected argument 'redirect_configurations' to be a list")
        pulumi.set(__self__, "redirect_configurations", redirect_configurations)
        if request_routing_rules and not isinstance(request_routing_rules, list):
            raise TypeError("Expected argument 'request_routing_rules' to be a list")
        pulumi.set(__self__, "request_routing_rules", request_routing_rules)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if rewrite_rule_sets and not isinstance(rewrite_rule_sets, list):
            raise TypeError("Expected argument 'rewrite_rule_sets' to be a list")
        pulumi.set(__self__, "rewrite_rule_sets", rewrite_rule_sets)
        if skus and not isinstance(skus, list):
            raise TypeError("Expected argument 'skus' to be a list")
        pulumi.set(__self__, "skus", skus)
        if ssl_certificates and not isinstance(ssl_certificates, list):
            raise TypeError("Expected argument 'ssl_certificates' to be a list")
        pulumi.set(__self__, "ssl_certificates", ssl_certificates)
        if ssl_policies and not isinstance(ssl_policies, list):
            raise TypeError("Expected argument 'ssl_policies' to be a list")
        pulumi.set(__self__, "ssl_policies", ssl_policies)
        if ssl_profiles and not isinstance(ssl_profiles, list):
            raise TypeError("Expected argument 'ssl_profiles' to be a list")
        pulumi.set(__self__, "ssl_profiles", ssl_profiles)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if trusted_client_certificates and not isinstance(trusted_client_certificates, list):
            raise TypeError("Expected argument 'trusted_client_certificates' to be a list")
        pulumi.set(__self__, "trusted_client_certificates", trusted_client_certificates)
        if trusted_root_certificates and not isinstance(trusted_root_certificates, list):
            raise TypeError("Expected argument 'trusted_root_certificates' to be a list")
        pulumi.set(__self__, "trusted_root_certificates", trusted_root_certificates)
        if url_path_maps and not isinstance(url_path_maps, list):
            raise TypeError("Expected argument 'url_path_maps' to be a list")
        pulumi.set(__self__, "url_path_maps", url_path_maps)
        if waf_configurations and not isinstance(waf_configurations, list):
            raise TypeError("Expected argument 'waf_configurations' to be a list")
        pulumi.set(__self__, "waf_configurations", waf_configurations)
        if zones and not isinstance(zones, list):
            raise TypeError("Expected argument 'zones' to be a list")
        pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter(name="authenticationCertificates")
    def authentication_certificates(self) -> Sequence['outputs.GetApplicationGatewayAuthenticationCertificateResult']:
        """
        One or more `authentication_certificate` blocks as defined below.
        """
        return pulumi.get(self, "authentication_certificates")

    @property
    @pulumi.getter(name="autoscaleConfigurations")
    def autoscale_configurations(self) -> Sequence['outputs.GetApplicationGatewayAutoscaleConfigurationResult']:
        """
        An `autoscale_configuration` block as defined below.
        """
        return pulumi.get(self, "autoscale_configurations")

    @property
    @pulumi.getter(name="backendAddressPools")
    def backend_address_pools(self) -> Sequence['outputs.GetApplicationGatewayBackendAddressPoolResult']:
        """
        One or more `backend_address_pool` blocks as defined below.
        """
        return pulumi.get(self, "backend_address_pools")

    @property
    @pulumi.getter(name="backendHttpSettings")
    def backend_http_settings(self) -> Sequence['outputs.GetApplicationGatewayBackendHttpSettingResult']:
        """
        One or more `backend_http_settings` blocks as defined below.
        """
        return pulumi.get(self, "backend_http_settings")

    @property
    @pulumi.getter(name="customErrorConfigurations")
    def custom_error_configurations(self) -> Sequence['outputs.GetApplicationGatewayCustomErrorConfigurationResult']:
        """
        One or more `custom_error_configuration` blocks as defined below.
        """
        return pulumi.get(self, "custom_error_configurations")

    @property
    @pulumi.getter(name="fipsEnabled")
    def fips_enabled(self) -> bool:
        """
        Is FIPS enabled on the Application Gateway?
        """
        return pulumi.get(self, "fips_enabled")

    @property
    @pulumi.getter(name="firewallPolicyId")
    def firewall_policy_id(self) -> str:
        """
        The ID of the Web Application Firewall Policy which is used as an HTTP Listener for this Path Rule.
        """
        return pulumi.get(self, "firewall_policy_id")

    @property
    @pulumi.getter(name="forceFirewallPolicyAssociation")
    def force_firewall_policy_association(self) -> bool:
        """
        Is the Firewall Policy associated with the Application Gateway?
        """
        return pulumi.get(self, "force_firewall_policy_association")

    @property
    @pulumi.getter(name="frontendIpConfigurations")
    def frontend_ip_configurations(self) -> Sequence['outputs.GetApplicationGatewayFrontendIpConfigurationResult']:
        """
        One or more `frontend_ip_configuration` blocks as defined below.
        """
        return pulumi.get(self, "frontend_ip_configurations")

    @property
    @pulumi.getter(name="frontendPorts")
    def frontend_ports(self) -> Sequence['outputs.GetApplicationGatewayFrontendPortResult']:
        """
        One or more `frontend_port` blocks as defined below.
        """
        return pulumi.get(self, "frontend_ports")

    @property
    @pulumi.getter(name="gatewayIpConfigurations")
    def gateway_ip_configurations(self) -> Sequence['outputs.GetApplicationGatewayGatewayIpConfigurationResult']:
        """
        One or more `gateway_ip_configuration` blocks as defined below.
        """
        return pulumi.get(self, "gateway_ip_configurations")

    @property
    @pulumi.getter
    def globals(self) -> Sequence['outputs.GetApplicationGatewayGlobalResult']:
        """
        A `global` block as defined below.
        """
        return pulumi.get(self, "globals")

    @property
    @pulumi.getter(name="http2Enabled")
    def http2_enabled(self) -> bool:
        """
        Is HTTP2 enabled on the application gateway resource?
        """
        return pulumi.get(self, "http2_enabled")

    @property
    @pulumi.getter(name="httpListeners")
    def http_listeners(self) -> Sequence['outputs.GetApplicationGatewayHttpListenerResult']:
        """
        One or more `http_listener` blocks as defined below.
        """
        return pulumi.get(self, "http_listeners")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def identities(self) -> Sequence['outputs.GetApplicationGatewayIdentityResult']:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identities")

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        The Azure region where the Application Gateway exists.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Unique name of the Rewrite Rule
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="privateEndpointConnections")
    def private_endpoint_connections(self) -> Sequence['outputs.GetApplicationGatewayPrivateEndpointConnectionResult']:
        return pulumi.get(self, "private_endpoint_connections")

    @property
    @pulumi.getter(name="privateLinkConfigurations")
    def private_link_configurations(self) -> Sequence['outputs.GetApplicationGatewayPrivateLinkConfigurationResult']:
        """
        One or more `private_link_configuration` blocks as defined below.
        """
        return pulumi.get(self, "private_link_configurations")

    @property
    @pulumi.getter
    def probes(self) -> Sequence['outputs.GetApplicationGatewayProbeResult']:
        """
        One or more `probe` blocks as defined below.
        """
        return pulumi.get(self, "probes")

    @property
    @pulumi.getter(name="redirectConfigurations")
    def redirect_configurations(self) -> Sequence['outputs.GetApplicationGatewayRedirectConfigurationResult']:
        """
        One or more `redirect_configuration` blocks as defined below.
        """
        return pulumi.get(self, "redirect_configurations")

    @property
    @pulumi.getter(name="requestRoutingRules")
    def request_routing_rules(self) -> Sequence['outputs.GetApplicationGatewayRequestRoutingRuleResult']:
        """
        One or more `request_routing_rule` blocks as defined below.
        """
        return pulumi.get(self, "request_routing_rules")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> str:
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="rewriteRuleSets")
    def rewrite_rule_sets(self) -> Sequence['outputs.GetApplicationGatewayRewriteRuleSetResult']:
        """
        One or more `rewrite_rule_set` blocks as defined below.
        """
        return pulumi.get(self, "rewrite_rule_sets")

    @property
    @pulumi.getter
    def skus(self) -> Sequence['outputs.GetApplicationGatewaySkusResult']:
        """
        A `sku` block as defined below.
        """
        return pulumi.get(self, "skus")

    @property
    @pulumi.getter(name="sslCertificates")
    def ssl_certificates(self) -> Sequence['outputs.GetApplicationGatewaySslCertificateResult']:
        """
        One or more `ssl_certificate` blocks as defined below.
        """
        return pulumi.get(self, "ssl_certificates")

    @property
    @pulumi.getter(name="sslPolicies")
    def ssl_policies(self) -> Sequence['outputs.GetApplicationGatewaySslPolicyResult']:
        """
        a `ssl_policy` block as defined below.
        """
        return pulumi.get(self, "ssl_policies")

    @property
    @pulumi.getter(name="sslProfiles")
    def ssl_profiles(self) -> Sequence['outputs.GetApplicationGatewaySslProfileResult']:
        """
        One or more `ssl_profile` blocks as defined below.
        """
        return pulumi.get(self, "ssl_profiles")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trustedClientCertificates")
    def trusted_client_certificates(self) -> Sequence['outputs.GetApplicationGatewayTrustedClientCertificateResult']:
        """
        One or more `trusted_client_certificate` blocks as defined below.
        """
        return pulumi.get(self, "trusted_client_certificates")

    @property
    @pulumi.getter(name="trustedRootCertificates")
    def trusted_root_certificates(self) -> Sequence['outputs.GetApplicationGatewayTrustedRootCertificateResult']:
        """
        One or more `trusted_root_certificate` blocks as defined below.
        """
        return pulumi.get(self, "trusted_root_certificates")

    @property
    @pulumi.getter(name="urlPathMaps")
    def url_path_maps(self) -> Sequence['outputs.GetApplicationGatewayUrlPathMapResult']:
        """
        One or more `url_path_map` blocks as defined below.
        """
        return pulumi.get(self, "url_path_maps")

    @property
    @pulumi.getter(name="wafConfigurations")
    def waf_configurations(self) -> Sequence['outputs.GetApplicationGatewayWafConfigurationResult']:
        """
        A `waf_configuration` block as defined below.
        """
        return pulumi.get(self, "waf_configurations")

    @property
    @pulumi.getter
    def zones(self) -> Sequence[str]:
        """
        The list of Availability Zones in which this Application Gateway can use.
        """
        return pulumi.get(self, "zones")


class AwaitableGetApplicationGatewayResult(GetApplicationGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetApplicationGatewayResult(
            authentication_certificates=self.authentication_certificates,
            autoscale_configurations=self.autoscale_configurations,
            backend_address_pools=self.backend_address_pools,
            backend_http_settings=self.backend_http_settings,
            custom_error_configurations=self.custom_error_configurations,
            fips_enabled=self.fips_enabled,
            firewall_policy_id=self.firewall_policy_id,
            force_firewall_policy_association=self.force_firewall_policy_association,
            frontend_ip_configurations=self.frontend_ip_configurations,
            frontend_ports=self.frontend_ports,
            gateway_ip_configurations=self.gateway_ip_configurations,
            globals=self.globals,
            http2_enabled=self.http2_enabled,
            http_listeners=self.http_listeners,
            id=self.id,
            identities=self.identities,
            location=self.location,
            name=self.name,
            private_endpoint_connections=self.private_endpoint_connections,
            private_link_configurations=self.private_link_configurations,
            probes=self.probes,
            redirect_configurations=self.redirect_configurations,
            request_routing_rules=self.request_routing_rules,
            resource_group_name=self.resource_group_name,
            rewrite_rule_sets=self.rewrite_rule_sets,
            skus=self.skus,
            ssl_certificates=self.ssl_certificates,
            ssl_policies=self.ssl_policies,
            ssl_profiles=self.ssl_profiles,
            tags=self.tags,
            trusted_client_certificates=self.trusted_client_certificates,
            trusted_root_certificates=self.trusted_root_certificates,
            url_path_maps=self.url_path_maps,
            waf_configurations=self.waf_configurations,
            zones=self.zones)


def get_application_gateway(name: Optional[str] = None,
                            resource_group_name: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetApplicationGatewayResult:
    """
    Use this data source to access information about an existing Application Gateway.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.network.get_application_gateway(name="existing-app-gateway",
        resource_group_name="existing-resources")
    pulumi.export("id", example.id)
    ```


    :param str name: The name of this Application Gateway.
    :param str resource_group_name: The name of the Resource Group where the Application Gateway exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:network/getApplicationGateway:getApplicationGateway', __args__, opts=opts, typ=GetApplicationGatewayResult).value

    return AwaitableGetApplicationGatewayResult(
        authentication_certificates=pulumi.get(__ret__, 'authentication_certificates'),
        autoscale_configurations=pulumi.get(__ret__, 'autoscale_configurations'),
        backend_address_pools=pulumi.get(__ret__, 'backend_address_pools'),
        backend_http_settings=pulumi.get(__ret__, 'backend_http_settings'),
        custom_error_configurations=pulumi.get(__ret__, 'custom_error_configurations'),
        fips_enabled=pulumi.get(__ret__, 'fips_enabled'),
        firewall_policy_id=pulumi.get(__ret__, 'firewall_policy_id'),
        force_firewall_policy_association=pulumi.get(__ret__, 'force_firewall_policy_association'),
        frontend_ip_configurations=pulumi.get(__ret__, 'frontend_ip_configurations'),
        frontend_ports=pulumi.get(__ret__, 'frontend_ports'),
        gateway_ip_configurations=pulumi.get(__ret__, 'gateway_ip_configurations'),
        globals=pulumi.get(__ret__, 'globals'),
        http2_enabled=pulumi.get(__ret__, 'http2_enabled'),
        http_listeners=pulumi.get(__ret__, 'http_listeners'),
        id=pulumi.get(__ret__, 'id'),
        identities=pulumi.get(__ret__, 'identities'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        private_endpoint_connections=pulumi.get(__ret__, 'private_endpoint_connections'),
        private_link_configurations=pulumi.get(__ret__, 'private_link_configurations'),
        probes=pulumi.get(__ret__, 'probes'),
        redirect_configurations=pulumi.get(__ret__, 'redirect_configurations'),
        request_routing_rules=pulumi.get(__ret__, 'request_routing_rules'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        rewrite_rule_sets=pulumi.get(__ret__, 'rewrite_rule_sets'),
        skus=pulumi.get(__ret__, 'skus'),
        ssl_certificates=pulumi.get(__ret__, 'ssl_certificates'),
        ssl_policies=pulumi.get(__ret__, 'ssl_policies'),
        ssl_profiles=pulumi.get(__ret__, 'ssl_profiles'),
        tags=pulumi.get(__ret__, 'tags'),
        trusted_client_certificates=pulumi.get(__ret__, 'trusted_client_certificates'),
        trusted_root_certificates=pulumi.get(__ret__, 'trusted_root_certificates'),
        url_path_maps=pulumi.get(__ret__, 'url_path_maps'),
        waf_configurations=pulumi.get(__ret__, 'waf_configurations'),
        zones=pulumi.get(__ret__, 'zones'))
def get_application_gateway_output(name: Optional[pulumi.Input[str]] = None,
                                   resource_group_name: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetApplicationGatewayResult]:
    """
    Use this data source to access information about an existing Application Gateway.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.network.get_application_gateway(name="existing-app-gateway",
        resource_group_name="existing-resources")
    pulumi.export("id", example.id)
    ```


    :param str name: The name of this Application Gateway.
    :param str resource_group_name: The name of the Resource Group where the Application Gateway exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:network/getApplicationGateway:getApplicationGateway', __args__, opts=opts, typ=GetApplicationGatewayResult)
    return __ret__.apply(lambda __response__: GetApplicationGatewayResult(
        authentication_certificates=pulumi.get(__response__, 'authentication_certificates'),
        autoscale_configurations=pulumi.get(__response__, 'autoscale_configurations'),
        backend_address_pools=pulumi.get(__response__, 'backend_address_pools'),
        backend_http_settings=pulumi.get(__response__, 'backend_http_settings'),
        custom_error_configurations=pulumi.get(__response__, 'custom_error_configurations'),
        fips_enabled=pulumi.get(__response__, 'fips_enabled'),
        firewall_policy_id=pulumi.get(__response__, 'firewall_policy_id'),
        force_firewall_policy_association=pulumi.get(__response__, 'force_firewall_policy_association'),
        frontend_ip_configurations=pulumi.get(__response__, 'frontend_ip_configurations'),
        frontend_ports=pulumi.get(__response__, 'frontend_ports'),
        gateway_ip_configurations=pulumi.get(__response__, 'gateway_ip_configurations'),
        globals=pulumi.get(__response__, 'globals'),
        http2_enabled=pulumi.get(__response__, 'http2_enabled'),
        http_listeners=pulumi.get(__response__, 'http_listeners'),
        id=pulumi.get(__response__, 'id'),
        identities=pulumi.get(__response__, 'identities'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        private_endpoint_connections=pulumi.get(__response__, 'private_endpoint_connections'),
        private_link_configurations=pulumi.get(__response__, 'private_link_configurations'),
        probes=pulumi.get(__response__, 'probes'),
        redirect_configurations=pulumi.get(__response__, 'redirect_configurations'),
        request_routing_rules=pulumi.get(__response__, 'request_routing_rules'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        rewrite_rule_sets=pulumi.get(__response__, 'rewrite_rule_sets'),
        skus=pulumi.get(__response__, 'skus'),
        ssl_certificates=pulumi.get(__response__, 'ssl_certificates'),
        ssl_policies=pulumi.get(__response__, 'ssl_policies'),
        ssl_profiles=pulumi.get(__response__, 'ssl_profiles'),
        tags=pulumi.get(__response__, 'tags'),
        trusted_client_certificates=pulumi.get(__response__, 'trusted_client_certificates'),
        trusted_root_certificates=pulumi.get(__response__, 'trusted_root_certificates'),
        url_path_maps=pulumi.get(__response__, 'url_path_maps'),
        waf_configurations=pulumi.get(__response__, 'waf_configurations'),
        zones=pulumi.get(__response__, 'zones')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['MoverJobDefinitionArgs', 'MoverJobDefinition']

@pulumi.input_type
class MoverJobDefinitionArgs:
    def __init__(__self__, *,
                 copy_mode: pulumi.Input[str],
                 source_name: pulumi.Input[str],
                 storage_mover_project_id: pulumi.Input[str],
                 target_name: pulumi.Input[str],
                 agent_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 source_sub_path: Optional[pulumi.Input[str]] = None,
                 target_sub_path: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a MoverJobDefinition resource.
        :param pulumi.Input[str] copy_mode: Specifies the strategy to use for copy. Possible values are `Additive` and `Mirror`.
        :param pulumi.Input[str] source_name: Specifies the name of the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] storage_mover_project_id: Specifies the ID of the Storage Mover Project. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_name: Specifies the name of the Storage Mover target Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] agent_name: Specifies the name of the Storage Mover Agent to assign for new Job Runs of this Storage Mover Job Definition.
        :param pulumi.Input[str] description: Specifies a description for this Storage Mover Job Definition.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Storage Mover Job Definition. Changing this forces a new resource to be created.
        :param pulumi.Input[str] source_sub_path: Specifies the sub path to use when reading from the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_sub_path: Specifies the sub path to use when writing to the Storage Mover Target Endpoint. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "copy_mode", copy_mode)
        pulumi.set(__self__, "source_name", source_name)
        pulumi.set(__self__, "storage_mover_project_id", storage_mover_project_id)
        pulumi.set(__self__, "target_name", target_name)
        if agent_name is not None:
            pulumi.set(__self__, "agent_name", agent_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if source_sub_path is not None:
            pulumi.set(__self__, "source_sub_path", source_sub_path)
        if target_sub_path is not None:
            pulumi.set(__self__, "target_sub_path", target_sub_path)

    @property
    @pulumi.getter(name="copyMode")
    def copy_mode(self) -> pulumi.Input[str]:
        """
        Specifies the strategy to use for copy. Possible values are `Additive` and `Mirror`.
        """
        return pulumi.get(self, "copy_mode")

    @copy_mode.setter
    def copy_mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "copy_mode", value)

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> pulumi.Input[str]:
        """
        Specifies the name of the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "source_name")

    @source_name.setter
    def source_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_name", value)

    @property
    @pulumi.getter(name="storageMoverProjectId")
    def storage_mover_project_id(self) -> pulumi.Input[str]:
        """
        Specifies the ID of the Storage Mover Project. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "storage_mover_project_id")

    @storage_mover_project_id.setter
    def storage_mover_project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "storage_mover_project_id", value)

    @property
    @pulumi.getter(name="targetName")
    def target_name(self) -> pulumi.Input[str]:
        """
        Specifies the name of the Storage Mover target Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "target_name")

    @target_name.setter
    def target_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "target_name", value)

    @property
    @pulumi.getter(name="agentName")
    def agent_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Storage Mover Agent to assign for new Job Runs of this Storage Mover Job Definition.
        """
        return pulumi.get(self, "agent_name")

    @agent_name.setter
    def agent_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "agent_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies a description for this Storage Mover Job Definition.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name which should be used for this Storage Mover Job Definition. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="sourceSubPath")
    def source_sub_path(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the sub path to use when reading from the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "source_sub_path")

    @source_sub_path.setter
    def source_sub_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_sub_path", value)

    @property
    @pulumi.getter(name="targetSubPath")
    def target_sub_path(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the sub path to use when writing to the Storage Mover Target Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "target_sub_path")

    @target_sub_path.setter
    def target_sub_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_sub_path", value)


@pulumi.input_type
class _MoverJobDefinitionState:
    def __init__(__self__, *,
                 agent_name: Optional[pulumi.Input[str]] = None,
                 copy_mode: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 source_name: Optional[pulumi.Input[str]] = None,
                 source_sub_path: Optional[pulumi.Input[str]] = None,
                 storage_mover_project_id: Optional[pulumi.Input[str]] = None,
                 target_name: Optional[pulumi.Input[str]] = None,
                 target_sub_path: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MoverJobDefinition resources.
        :param pulumi.Input[str] agent_name: Specifies the name of the Storage Mover Agent to assign for new Job Runs of this Storage Mover Job Definition.
        :param pulumi.Input[str] copy_mode: Specifies the strategy to use for copy. Possible values are `Additive` and `Mirror`.
        :param pulumi.Input[str] description: Specifies a description for this Storage Mover Job Definition.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Storage Mover Job Definition. Changing this forces a new resource to be created.
        :param pulumi.Input[str] source_name: Specifies the name of the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] source_sub_path: Specifies the sub path to use when reading from the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] storage_mover_project_id: Specifies the ID of the Storage Mover Project. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_name: Specifies the name of the Storage Mover target Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_sub_path: Specifies the sub path to use when writing to the Storage Mover Target Endpoint. Changing this forces a new resource to be created.
        """
        if agent_name is not None:
            pulumi.set(__self__, "agent_name", agent_name)
        if copy_mode is not None:
            pulumi.set(__self__, "copy_mode", copy_mode)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if source_name is not None:
            pulumi.set(__self__, "source_name", source_name)
        if source_sub_path is not None:
            pulumi.set(__self__, "source_sub_path", source_sub_path)
        if storage_mover_project_id is not None:
            pulumi.set(__self__, "storage_mover_project_id", storage_mover_project_id)
        if target_name is not None:
            pulumi.set(__self__, "target_name", target_name)
        if target_sub_path is not None:
            pulumi.set(__self__, "target_sub_path", target_sub_path)

    @property
    @pulumi.getter(name="agentName")
    def agent_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Storage Mover Agent to assign for new Job Runs of this Storage Mover Job Definition.
        """
        return pulumi.get(self, "agent_name")

    @agent_name.setter
    def agent_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "agent_name", value)

    @property
    @pulumi.getter(name="copyMode")
    def copy_mode(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the strategy to use for copy. Possible values are `Additive` and `Mirror`.
        """
        return pulumi.get(self, "copy_mode")

    @copy_mode.setter
    def copy_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "copy_mode", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies a description for this Storage Mover Job Definition.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name which should be used for this Storage Mover Job Definition. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "source_name")

    @source_name.setter
    def source_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_name", value)

    @property
    @pulumi.getter(name="sourceSubPath")
    def source_sub_path(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the sub path to use when reading from the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "source_sub_path")

    @source_sub_path.setter
    def source_sub_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_sub_path", value)

    @property
    @pulumi.getter(name="storageMoverProjectId")
    def storage_mover_project_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the ID of the Storage Mover Project. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "storage_mover_project_id")

    @storage_mover_project_id.setter
    def storage_mover_project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "storage_mover_project_id", value)

    @property
    @pulumi.getter(name="targetName")
    def target_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Storage Mover target Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "target_name")

    @target_name.setter
    def target_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_name", value)

    @property
    @pulumi.getter(name="targetSubPath")
    def target_sub_path(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the sub path to use when writing to the Storage Mover Target Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "target_sub_path")

    @target_sub_path.setter
    def target_sub_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_sub_path", value)


class MoverJobDefinition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_name: Optional[pulumi.Input[str]] = None,
                 copy_mode: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 source_name: Optional[pulumi.Input[str]] = None,
                 source_sub_path: Optional[pulumi.Input[str]] = None,
                 storage_mover_project_id: Optional[pulumi.Input[str]] = None,
                 target_name: Optional[pulumi.Input[str]] = None,
                 target_sub_path: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Storage Mover Job Definition.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_mover = azure.storage.Mover("example",
            name="example-ssm",
            resource_group_name=example.name,
            location=example.location)
        example_mover_agent = azure.storage.MoverAgent("example",
            name="example-agent",
            storage_mover_id=example_mover.id,
            arc_virtual_machine_id=example.id.apply(lambda id: f"{id}/providers/Microsoft.HybridCompute/machines/examples-hybridComputeName"),
            arc_virtual_machine_uuid="3bb2c024-eba9-4d18-9e7a-1d772fcc5fe9")
        example_account = azure.storage.Account("example",
            name="examplesa",
            resource_group_name=example.name,
            location=example.location,
            account_tier="Standard",
            account_replication_type="LRS",
            allow_nested_items_to_be_public=True)
        example_container = azure.storage.Container("example",
            name="acccontainer",
            storage_account_name=example_account.name,
            container_access_type="blob")
        example_mover_target_endpoint = azure.storage.MoverTargetEndpoint("example",
            name="example-smte",
            storage_mover_id=example_mover.id,
            storage_account_id=example_account.id,
            storage_container_name=example_container.name)
        example_mover_source_endpoint = azure.storage.MoverSourceEndpoint("example",
            name="example-smse",
            storage_mover_id=example_mover.id,
            host="192.168.0.1")
        example_mover_project = azure.storage.MoverProject("example",
            name="example-sp",
            storage_mover_id=example_mover.id)
        example_mover_job_definition = azure.storage.MoverJobDefinition("example",
            name="example-sjd",
            storage_mover_project_id=example_mover_project.id,
            agent_name=example_mover_agent.name,
            copy_mode="Additive",
            source_name=example_mover_source_endpoint.name,
            source_sub_path="/",
            target_name=example_mover_target_endpoint.name,
            target_sub_path="/",
            description="Example Job Definition Description")
        ```

        ## Import

        Storage Mover Job Definition can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:storage/moverJobDefinition:MoverJobDefinition example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.StorageMover/storageMovers/storageMover1/projects/project1/jobDefinitions/jobDefinition1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] agent_name: Specifies the name of the Storage Mover Agent to assign for new Job Runs of this Storage Mover Job Definition.
        :param pulumi.Input[str] copy_mode: Specifies the strategy to use for copy. Possible values are `Additive` and `Mirror`.
        :param pulumi.Input[str] description: Specifies a description for this Storage Mover Job Definition.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Storage Mover Job Definition. Changing this forces a new resource to be created.
        :param pulumi.Input[str] source_name: Specifies the name of the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] source_sub_path: Specifies the sub path to use when reading from the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] storage_mover_project_id: Specifies the ID of the Storage Mover Project. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_name: Specifies the name of the Storage Mover target Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_sub_path: Specifies the sub path to use when writing to the Storage Mover Target Endpoint. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MoverJobDefinitionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Storage Mover Job Definition.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_mover = azure.storage.Mover("example",
            name="example-ssm",
            resource_group_name=example.name,
            location=example.location)
        example_mover_agent = azure.storage.MoverAgent("example",
            name="example-agent",
            storage_mover_id=example_mover.id,
            arc_virtual_machine_id=example.id.apply(lambda id: f"{id}/providers/Microsoft.HybridCompute/machines/examples-hybridComputeName"),
            arc_virtual_machine_uuid="3bb2c024-eba9-4d18-9e7a-1d772fcc5fe9")
        example_account = azure.storage.Account("example",
            name="examplesa",
            resource_group_name=example.name,
            location=example.location,
            account_tier="Standard",
            account_replication_type="LRS",
            allow_nested_items_to_be_public=True)
        example_container = azure.storage.Container("example",
            name="acccontainer",
            storage_account_name=example_account.name,
            container_access_type="blob")
        example_mover_target_endpoint = azure.storage.MoverTargetEndpoint("example",
            name="example-smte",
            storage_mover_id=example_mover.id,
            storage_account_id=example_account.id,
            storage_container_name=example_container.name)
        example_mover_source_endpoint = azure.storage.MoverSourceEndpoint("example",
            name="example-smse",
            storage_mover_id=example_mover.id,
            host="192.168.0.1")
        example_mover_project = azure.storage.MoverProject("example",
            name="example-sp",
            storage_mover_id=example_mover.id)
        example_mover_job_definition = azure.storage.MoverJobDefinition("example",
            name="example-sjd",
            storage_mover_project_id=example_mover_project.id,
            agent_name=example_mover_agent.name,
            copy_mode="Additive",
            source_name=example_mover_source_endpoint.name,
            source_sub_path="/",
            target_name=example_mover_target_endpoint.name,
            target_sub_path="/",
            description="Example Job Definition Description")
        ```

        ## Import

        Storage Mover Job Definition can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:storage/moverJobDefinition:MoverJobDefinition example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.StorageMover/storageMovers/storageMover1/projects/project1/jobDefinitions/jobDefinition1
        ```

        :param str resource_name: The name of the resource.
        :param MoverJobDefinitionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MoverJobDefinitionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_name: Optional[pulumi.Input[str]] = None,
                 copy_mode: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 source_name: Optional[pulumi.Input[str]] = None,
                 source_sub_path: Optional[pulumi.Input[str]] = None,
                 storage_mover_project_id: Optional[pulumi.Input[str]] = None,
                 target_name: Optional[pulumi.Input[str]] = None,
                 target_sub_path: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MoverJobDefinitionArgs.__new__(MoverJobDefinitionArgs)

            __props__.__dict__["agent_name"] = agent_name
            if copy_mode is None and not opts.urn:
                raise TypeError("Missing required property 'copy_mode'")
            __props__.__dict__["copy_mode"] = copy_mode
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if source_name is None and not opts.urn:
                raise TypeError("Missing required property 'source_name'")
            __props__.__dict__["source_name"] = source_name
            __props__.__dict__["source_sub_path"] = source_sub_path
            if storage_mover_project_id is None and not opts.urn:
                raise TypeError("Missing required property 'storage_mover_project_id'")
            __props__.__dict__["storage_mover_project_id"] = storage_mover_project_id
            if target_name is None and not opts.urn:
                raise TypeError("Missing required property 'target_name'")
            __props__.__dict__["target_name"] = target_name
            __props__.__dict__["target_sub_path"] = target_sub_path
        super(MoverJobDefinition, __self__).__init__(
            'azure:storage/moverJobDefinition:MoverJobDefinition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agent_name: Optional[pulumi.Input[str]] = None,
            copy_mode: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            source_name: Optional[pulumi.Input[str]] = None,
            source_sub_path: Optional[pulumi.Input[str]] = None,
            storage_mover_project_id: Optional[pulumi.Input[str]] = None,
            target_name: Optional[pulumi.Input[str]] = None,
            target_sub_path: Optional[pulumi.Input[str]] = None) -> 'MoverJobDefinition':
        """
        Get an existing MoverJobDefinition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] agent_name: Specifies the name of the Storage Mover Agent to assign for new Job Runs of this Storage Mover Job Definition.
        :param pulumi.Input[str] copy_mode: Specifies the strategy to use for copy. Possible values are `Additive` and `Mirror`.
        :param pulumi.Input[str] description: Specifies a description for this Storage Mover Job Definition.
        :param pulumi.Input[str] name: Specifies the name which should be used for this Storage Mover Job Definition. Changing this forces a new resource to be created.
        :param pulumi.Input[str] source_name: Specifies the name of the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] source_sub_path: Specifies the sub path to use when reading from the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] storage_mover_project_id: Specifies the ID of the Storage Mover Project. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_name: Specifies the name of the Storage Mover target Endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_sub_path: Specifies the sub path to use when writing to the Storage Mover Target Endpoint. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MoverJobDefinitionState.__new__(_MoverJobDefinitionState)

        __props__.__dict__["agent_name"] = agent_name
        __props__.__dict__["copy_mode"] = copy_mode
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["source_name"] = source_name
        __props__.__dict__["source_sub_path"] = source_sub_path
        __props__.__dict__["storage_mover_project_id"] = storage_mover_project_id
        __props__.__dict__["target_name"] = target_name
        __props__.__dict__["target_sub_path"] = target_sub_path
        return MoverJobDefinition(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="agentName")
    def agent_name(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the name of the Storage Mover Agent to assign for new Job Runs of this Storage Mover Job Definition.
        """
        return pulumi.get(self, "agent_name")

    @property
    @pulumi.getter(name="copyMode")
    def copy_mode(self) -> pulumi.Output[str]:
        """
        Specifies the strategy to use for copy. Possible values are `Additive` and `Mirror`.
        """
        return pulumi.get(self, "copy_mode")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies a description for this Storage Mover Job Definition.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Specifies the name which should be used for this Storage Mover Job Definition. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "source_name")

    @property
    @pulumi.getter(name="sourceSubPath")
    def source_sub_path(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the sub path to use when reading from the Storage Mover Source Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "source_sub_path")

    @property
    @pulumi.getter(name="storageMoverProjectId")
    def storage_mover_project_id(self) -> pulumi.Output[str]:
        """
        Specifies the ID of the Storage Mover Project. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "storage_mover_project_id")

    @property
    @pulumi.getter(name="targetName")
    def target_name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the Storage Mover target Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "target_name")

    @property
    @pulumi.getter(name="targetSubPath")
    def target_sub_path(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the sub path to use when writing to the Storage Mover Target Endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "target_sub_path")

